@@ -19,7 +19,7 @@
 #' proj_matrix(VarRubin.matrix, attr(datasim,"metadata"))
 proj_matrix <- function(VarRubin.matrix, metadata) {
   return(as.numeric(lapply(VarRubin.matrix, function(aaa){
-    DesMat = DAPAR::make.design(metadata)
+    DesMat = mi4p::make.design(metadata)
     max(diag(aaa)%*%t(DesMat)%*%DesMat)
   })))
 }
\ No newline at end of file
